@@ -11,7 +11,7 @@ from typing import Optional
 from ._job import Job
 from ._scheduler import ExceptionHandler, Scheduler
 
-__version__ = "1.3.0"
+__version__ = "1.4.0"
 
 
 async def create_scheduler(
@@ -19,14 +19,13 @@ async def create_scheduler(
     close_timeout: Optional[float] = 0.1,
     limit: Optional[int] = 100,
     pending_limit: int = 10000,
-    exception_handler: Optional[ExceptionHandler] = None
+    exception_handler: Optional[ExceptionHandler] = None,
 ) -> Scheduler:
     warnings.warn("Scheduler can now be instantiated directly.", DeprecationWarning)
 
     if exception_handler is not None and not callable(exception_handler):
         raise TypeError(
-            "A callable object or None is expected, "
-            "got {!r}".format(exception_handler)
+            f"A callable object or None is expected, got {exception_handler!r}"
         )
     return Scheduler(
         close_timeout=close_timeout,
