@@ -1,11 +1,12 @@
 import asyncio
 import sys
-from typing import Awaitable, Callable, List, NoReturn
+from collections.abc import Awaitable
+from typing import Callable, List, NoReturn
 from unittest import mock
 
 import pytest
 
-from aiojobs import Scheduler
+from aiojobs import Job, Scheduler
 
 if sys.version_info >= (3, 11):
     from asyncio import timeout as asyncio_timeout
@@ -19,6 +20,12 @@ def test_ctor(scheduler: Scheduler) -> None:
     assert len(scheduler) == 0
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason="Requires Python 3.10+")
+def test_ctor_without_loop() -> None:
+    scheduler = Scheduler()
+    assert len(scheduler) == 0
+
+
 async def test_spawn(scheduler: Scheduler) -> None:
     async def coro() -> None:
         await asyncio.sleep(1)
@@ -31,6 +38,69 @@ async def test_spawn(scheduler: Scheduler) -> None:
     assert job in scheduler
 
 
+@pytest.mark.skipif(sys.version_info < (3, 10), reason="Requires Python 3.10+")
+async def test_spawn_non_bound_loop() -> None:
+    loop = asyncio.get_running_loop()
+
+    async def coro() -> None:
+        await asyncio.sleep(1)
+
+    scheduler = await asyncio.to_thread(Scheduler)
+    assert scheduler._failed_task is None
+
+    job = await scheduler.spawn(coro())
+    assert not job.closed
+
+    ft = scheduler._failed_task
+    assert ft is not None
+    scheduler_loop = ft.get_loop()  # type: ignore[unreachable]
+    assert scheduler_loop is loop
+
+    assert len(scheduler) == 1
+    assert list(scheduler) == [job]
+    assert job in scheduler
+
+    await scheduler.close()
+
+
+@pytest.mark.skipif(sys.version_info < (3, 10), reason="Requires Python 3.10+")
+def test_spawn_with_different_loop() -> None:
+    async def func() -> None:
+        await asyncio.sleep(1)
+
+    scheduler = Scheduler()
+
+    async def spawn1() -> Job[None]:
+        job = await scheduler.spawn(func())
+        assert not job.closed
+
+        assert len(scheduler) == 1
+        assert list(scheduler) == [job]
+        assert job in scheduler
+
+        return job
+
+    async def spawn2() -> None:
+        coro = func()
+        with pytest.raises(RuntimeError, match=" is bound to a different event loop"):
+            await scheduler.spawn(coro)
+
+        await coro  # suppress a warning about non-awaited coroutine
+
+        assert len(scheduler) == 1
+        assert list(scheduler) == [job]
+
+    loop1 = asyncio.new_event_loop()
+    job = loop1.run_until_complete(spawn1())
+
+    loop2 = asyncio.new_event_loop()
+    loop2.run_until_complete(spawn2())
+
+    loop2.close()
+    loop1.run_until_complete(scheduler.close())
+    loop1.close()
+
+
 async def test_run_retval(scheduler: Scheduler) -> None:
     async def coro() -> int:
         return 1
@@ -246,9 +316,9 @@ async def test_pending_queue_infinite(make_scheduler: _MakeScheduler) -> None:
     async def coro(fut: "asyncio.Future[None]") -> None:
         await fut
 
-    fut1: "asyncio.Future[None]" = asyncio.Future()
-    fut2: "asyncio.Future[None]" = asyncio.Future()
-    fut3: "asyncio.Future[None]" = asyncio.Future()
+    fut1: asyncio.Future[None] = asyncio.Future()
+    fut2: asyncio.Future[None] = asyncio.Future()
+    fut3: asyncio.Future[None] = asyncio.Future()
 
     await scheduler.spawn(coro(fut1))
     assert scheduler.pending_count == 0
@@ -267,9 +337,9 @@ async def test_pending_queue_limit_wait(make_scheduler: _MakeScheduler) -> None:
         await asyncio.sleep(0)
         await fut
 
-    fut1: "asyncio.Future[None]" = asyncio.Future()
-    fut2: "asyncio.Future[None]" = asyncio.Future()
-    fut3: "asyncio.Future[None]" = asyncio.Future()
+    fut1: asyncio.Future[None] = asyncio.Future()
+    fut2: asyncio.Future[None] = asyncio.Future()
+    fut3: asyncio.Future[None] = asyncio.Future()
 
     await scheduler.spawn(coro(fut1))
     assert scheduler.active_count == 1
@@ -296,7 +366,7 @@ async def test_scheduler_concurrency_pending_limit(
     async def coro(fut: "asyncio.Future[object]") -> None:
         await fut
 
-    futures: List["asyncio.Future[object]"] = [asyncio.Future() for _ in range(3)]
+    futures: List[asyncio.Future[object]] = [asyncio.Future() for _ in range(3)]
     jobs = []
 
     async def spawn() -> None:
@@ -333,14 +403,14 @@ async def test_scheduler_concurrency_limit(make_scheduler: _MakeScheduler) -> No
     assert scheduler.active_count == 0
     assert scheduler.pending_count == 0
 
-    fut1: "asyncio.Future[None]" = asyncio.Future()
+    fut1: asyncio.Future[None] = asyncio.Future()
     job1 = await scheduler.spawn(coro(fut1))
 
     assert scheduler.active_count == 1
     assert scheduler.pending_count == 0
     assert job1.active
 
-    fut2: "asyncio.Future[None]" = asyncio.Future()
+    fut2: asyncio.Future[None] = asyncio.Future()
     job2 = await scheduler.spawn(coro(fut2))
 
     assert scheduler.active_count == 1
@@ -569,6 +639,29 @@ async def test_wait_and_close_spawn(scheduler: Scheduler) -> None:
     assert another_spawned and another_done  # type: ignore[unreachable]
 
 
+async def test_wait_and_close_exception(make_scheduler: _MakeScheduler) -> None:
+    exc_handler = mock.Mock()
+    scheduler = await make_scheduler(exception_handler=exc_handler)
+    exc = RuntimeError()
+
+    async def coro() -> NoReturn:
+        await asyncio.sleep(0)
+        raise exc
+
+    await scheduler.spawn(coro())
+    assert len(scheduler) == 1
+
+    await scheduler.wait_and_close()
+
+    assert len(scheduler) == 0
+
+    expect = {"exception": exc, "job": mock.ANY, "message": "Job processing failed"}
+    if asyncio.get_running_loop().get_debug():
+        expect["source_traceback"] = mock.ANY
+    exc_handler.assert_called_with(scheduler, expect)
+
+
+@pytest.mark.skipif(sys.version_info >= (3, 10), reason="Requires Python<3.10")
 def test_scheduler_must_be_created_within_running_loop() -> None:
     with pytest.raises(RuntimeError) as exc_info:
         Scheduler(close_timeout=0, limit=0, pending_limit=0, exception_handler=None)
